@@ -1,7 +1,7 @@
 package Log::ger::For::Package;
 
-our $DATE = '2017-06-19'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-07-30'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010;
 use strict;
@@ -66,7 +66,7 @@ sub _default_precall_logger {
             } else {
                 $cargs = "...";
             }
-            log_tracef("%s---> %s(%s)", $indent, $args->{name}, $cargs);
+            log_trace("%s---> %s(%s)", $indent, $args->{name}, $cargs);
         }
 
     }
@@ -378,7 +378,7 @@ Log::ger::For::Package - Add logging to package
 
 =head1 VERSION
 
-This document describes version 0.001 of Log::ger::For::Package (from Perl distribution Log-ger-For-Class), released on 2017-06-19.
+This document describes version 0.002 of Log::ger::For::Package (from Perl distribution Log-ger-For-Class), released on 2017-07-30.
 
 =head1 SYNOPSIS
 
